==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Members_List/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Internetadresse");
define("_EMAIL","E-mailadresse");
define("_REALNAME","Rigtige navn");
define("_FUNCTIONS","Funktioner");
define("_PREVIOUS","Forrige side");
define("_MEMBERSLIST"," - Medlemsliste");
define("_GREETINGS","Velkommen til vores sidst registrerede bruger:");
define("_SORTBY","Sorter efter:");
define("_MNICKNAME","brugernavn");
define("_MREALNAME","rigtige navn");
define("_MEMAIL","e-mailadresse");
define("_MURL","internetadresse");
define("_ONLINEREG","Brugere online lige nu:");
define("_WEHAVE","Vi har");
define("_MREGISTERED","brugere indtil videre. Der er");
define("_MREGONLINE","bruger(e) online lige nu.");
define("_REGSOFAR","brugere indtil videre.");
define("_USERSFOUND","brugere fundet efter");
define("_USERSSHOWN","brugere vist");
define("_NOMEMBERS","Ingen brugere fundet efter");
define("_PAGES","Sider");
define("_HOMEPAGE","Hjemmeside");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Members_List/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Internetadresse");
define("_EMAIL","E-mailadresse");
define("_REALNAME","Rigtige navn");
define("_FUNCTIONS","Funktioner");
define("_PREVIOUS","Forrige side");
define("_MEMBERSLIST"," - Medlemsliste");
define("_GREETINGS","Velkommen til vores sidst registrerede bruger:");
define("_SORTBY","Sorter efter:");
define("_MNICKNAME","brugernavn");
define("_MREALNAME","rigtige navn");
define("_MEMAIL","e-mailadresse");
define("_MURL","internetadresse");
define("_ONLINEREG","Brugere online lige nu:");
define("_WEHAVE","Vi har");
define("_MREGISTERED","brugere indtil videre. Der er");
define("_MREGONLINE","bruger(e) online lige nu.");
define("_REGSOFAR","brugere indtil videre.");
define("_USERSFOUND","brugere fundet efter");
define("_USERSSHOWN","brugere vist");
define("_NOMEMBERS","Ingen brugere fundet efter");
define("_PAGES","Sider");
define("_HOMEPAGE","Hjemmeside");

?>
